FL.helpers.classList.ClassList
==============================

.. currentmodule:: FL.helpers.classList

.. autoclass:: ClassList
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ClassList.GetClassLeft
      ~ClassList.GetClassMetricsFlags
      ~ClassList.GetClassRight
      ~ClassList.SetClassFlags
      ~ClassList.__init__
      ~ClassList.append
      ~ClassList.clear
      ~ClassList.copy
      ~ClassList.count
      ~ClassList.extend
      ~ClassList.fake_set_classes
      ~ClassList.index
      ~ClassList.insert
      ~ClassList.pop
      ~ClassList.remove
      ~ClassList.reverse
      ~ClassList.sort
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ClassList.fake_kerning_flags
      ~ClassList.fake_metrics_flags
   
   